@@ -105,6 +105,7 @@ class Nikola(object):
         # This is the default config
         self.config = {
             'ADD_THIS_BUTTONS': True,
+            'ANNOTATIONS': False,
             'ARCHIVE_PATH': "",
             'ARCHIVE_FILENAME': "archive.html",
             'BLOG_TITLE': 'Default Title',
@@ -142,6 +143,7 @@ class Nikola(object):
             'FILES_FOLDERS': {'files': ''},
             'FILTERS': {},
             'GALLERY_PATH': 'galleries',
+            'GALLERY_SORT_BY_DATE': True,
             'GZIP_COMMAND': None,
             'GZIP_FILES': False,
             'GZIP_EXTENSIONS': ('.txt', '.htm', '.html', '.css', '.js', '.json'),
@@ -154,6 +156,7 @@ class Nikola(object):
             'INDEXES_TITLE': "",
             'INDEXES_PAGES': "",
             'INDEX_PATH': '',
+            'IPYNB_CONFIG': {},
             'LICENSE': '',
             'LINK_CHECK_WHITELIST': [],
             'LISTINGS_FOLDER': 'listings',
@@ -377,9 +380,8 @@ class Nikola(object):
         self._GLOBAL_CONTEXT['rel_link'] = self.rel_link
         self._GLOBAL_CONTEXT['abs_link'] = self.abs_link
         self._GLOBAL_CONTEXT['exists'] = self.file_exists
-        self._GLOBAL_CONTEXT['SLUG_TAG_PATH'] = self.config[
-            'SLUG_TAG_PATH']
-
+        self._GLOBAL_CONTEXT['SLUG_TAG_PATH'] = self.config['SLUG_TAG_PATH']
+        self._GLOBAL_CONTEXT['annotations'] = self.config['ANNOTATIONS']
         self._GLOBAL_CONTEXT['index_display_post_count'] = self.config[
             'INDEX_DISPLAY_POST_COUNT']
         self._GLOBAL_CONTEXT['use_bundles'] = self.config['USE_BUNDLES']
@@ -652,6 +654,7 @@ class Nikola(object):
         * gallery (name is the gallery name)
         * listing (name is the source code file name)
         * post_path (name is 1st element in a POSTS/PAGES tuple)
+        * slug (name is the slug of a post or story)
 
         The returned value is always a path relative to output, like
         "categories/whatever.html"
@@ -729,6 +732,16 @@ class Nikola(object):
         elif kind == "listing":
             path = [_f for _f in [self.config['LISTINGS_FOLDER'], name +
                                   '.html'] if _f]
+        elif kind == "slug":
+            results = [p for p in self.timeline if p.meta('slug') == name]
+            if not results:
+                utils.LOGGER.warning("Can't resolve path request for slug: {0}".format(name))
+            else:
+                if len(results) > 1:
+                    utils.LOGGER.warning('Ambiguous path request for slug: {0}'.format(name))
+                path = [_f for _f in results[0].permalink(lang).split('/') if _f]
+                utils.LOGGER.notice(path)
+
         if is_link:
             link = '/' + ('/'.join(path))
             index_len = len(self.config['INDEX_FILE'])
@@ -788,7 +801,7 @@ class Nikola(object):
             task['targets'] = [os.path.normpath(t) for t in targets]
         return task
 
-    def gen_tasks(self, name, plugin_category):
+    def gen_tasks(self, name, plugin_category, doc=''):
 
         def flatten(task):
             if isinstance(task, dict):
@@ -801,6 +814,7 @@ class Nikola(object):
         task_dep = []
         for pluginInfo in self.plugin_manager.getPluginsOfCategory(plugin_category):
             for task in flatten(pluginInfo.plugin_object.gen_tasks()):
+                assert 'basename' in task
                 task = self.clean_task_paths(task)
                 yield task
                 for multi in self.plugin_manager.getPluginsOfCategory("TaskMultiplier"):
@@ -813,7 +827,8 @@ class Nikola(object):
             if pluginInfo.plugin_object.is_default:
                 task_dep.append(pluginInfo.plugin_object.name)
         yield {
-            'name': name,
+            'basename': name,
+            'doc': doc,
             'actions': None,
             'clean': True,
             'task_dep': task_dep
@@ -833,6 +848,7 @@ class Nikola(object):
         else:
             current_time = utils.current_time(tzinfo)
         targets = set([])
+        lower_case_tags = set([])
         for wildcard, destination, template_name, use_in_feeds in \
                 self.config['post_pages']:
             print(".", end='')
@@ -897,6 +913,16 @@ class Nikola(object):
                         self.posts_per_month[
                             '{0}/{1:02d}'.format(post.date.year, post.date.month)].append(post.post_name)
                         for tag in post.alltags:
+                            if tag.lower() in lower_case_tags:
+                                if tag not in self.posts_per_tag:
+                                    # Tags that differ only in case
+                                    other_tag = [k for k in self.posts_per_tag.keys() if k.lower() == tag.lower()][0]
+                                    utils.LOGGER.error('You have cases that differ only in upper/lower case: {0} and {1}'.format(tag, other_tag))
+                                    utils.LOGGER.error('Tag {0} is used in: {1}'.format(tag, post.post_name))
+                                    utils.LOGGER.error('Tag {0} is used in: {1}'.format(other_tag, ', '.join(self.posts_per_tag[other_tag])))
+                                    sys.exit(1)
+                            else:
+                                lower_case_tags.add(tag.lower())
                             self.posts_per_tag[tag].append(post.post_name)
                         self.posts_per_category[post.meta('category')].append(post.post_name)
                     else:
