@@ -55,6 +55,10 @@ class ApplicationWarning(Exception):
 
 LOGGER = logbook.Logger('Nikola')
 STRICT_HANDLER = ExceptionHandler(ApplicationWarning, level='WARNING')
+LOGGER.handlers.append(logbook.StderrHandler(
+    level=logbook.NOTICE,
+    format_string=u'[{record.time:%Y-%m-%dT%H:%M:%SZ}] {record.level_name}: {record.channel}: {record.message}'
+))
 
 if sys.version_info[0] == 3:
     # Python 3
@@ -78,7 +82,7 @@ __all__ = ['get_theme_path', 'get_theme_chain', 'load_messages', 'copy_tree',
            'to_datetime', 'apply_filters', 'config_changed', 'get_crumbs',
            'get_tzname', 'get_asset_path', '_reload', 'unicode_str', 'bytes_str',
            'unichr', 'Functionary', 'LocaleBorg', 'sys_encode', 'sys_decode',
-           'makedirs']
+           'makedirs', 'get_parent_theme_name']
 
 
 ENCODING = sys.getfilesystemencoding() or sys.stdin.encoding
@@ -118,6 +122,10 @@ class Functionary(defaultdict):
     def current_lang(self):
         """Guess the current language from locale or default."""
         lang = locale.getlocale()[0]
+        if lang is None:
+            # for python 2.x, see issues 12699 and 6203 in python bugtracker
+            locale.setlocale(locale.LC_ALL, '')
+            lang = locale.getlocale()[0]
         if lang:
             if lang in self.keys():
                 return lang
@@ -193,19 +201,20 @@ def get_template_engine(themes):
     return 'mako'
 
 
+def get_parent_theme_name(theme_name):
+    parent_path = os.path.join(get_theme_path(theme_name), 'parent')
+    if os.path.isfile(parent_path):
+        with open(parent_path) as fd:
+            return fd.readlines()[0].strip()
+    return None
+
+
 def get_theme_chain(theme):
     """Create the full theme inheritance chain."""
     themes = [theme]
 
-    def get_parent(theme_name):
-        parent_path = os.path.join(get_theme_path(theme_name), 'parent')
-        if os.path.isfile(parent_path):
-            with open(parent_path) as fd:
-                return fd.readlines()[0].strip()
-        return None
-
     while True:
-        parent = get_parent(themes[-1])
+        parent = get_parent_theme_name(themes[-1])
         # Avoid silly loops
         if parent is None or parent in themes:
             break
@@ -239,7 +248,7 @@ def load_messages(themes, translations, default_lang):
                     lang not in warned:
                 warned.append(lang)
                 LOGGER.warn("Incomplete translation for language "
-                      "'{0}'.".format(lang))
+                            "'{0}'.".format(lang))
             messages[lang].update(english.MESSAGES)
             messages[lang].update(translation.MESSAGES)
             del(translation)
@@ -299,6 +308,8 @@ def generic_rss_renderer(lang, title, link, description, timeline, output_path,
                         post.date.astimezone(pytz.timezone('UTC'))),
             'categories': post._tags.get(lang, []),
         }
+        if post.meta('author') is not None:
+            args['author'] = post.meta('author')
         items.append(rss.RSSItem(**args))
     rss_obj = ExtendedRSS2(
         title=title,
@@ -307,6 +318,7 @@ def generic_rss_renderer(lang, title, link, description, timeline, output_path,
         lastBuildDate=datetime.datetime.now(),
         items=items,
         generator='nikola',
+        language=lang
     )
     rss_obj.self_url = feed_url
     rss_obj.rss_attrs["xmlns:atom"] = "http://www.w3.org/2005/Atom"
@@ -395,9 +407,10 @@ class UnsafeZipException(Exception):
     pass
 
 
-def extract_all(zipfile):
+def extract_all(zipfile, path='themes'):
     pwd = os.getcwd()
-    os.chdir('themes')
+    makedirs(path)
+    os.chdir(path)
     with zip(zipfile) as z:
         namelist = z.namelist()
         for f in namelist:
@@ -447,7 +460,8 @@ def to_datetime(value, tzinfo=None):
         return tzinfo.localize(dt)
     except ImportError:
         raise ValueError('Unrecognized date/time: {0!r}, try installing dateutil...'.format(value))
-    raise ValueError('Unrecognized date/time: {0!r}'.format(value))
+    except Exception:
+        raise ValueError('Unrecognized date/time: {0!r}'.format(value))
 
 
 def get_tzname(dt):
@@ -555,25 +569,26 @@ def get_crumbs(path, is_file=False):
 
 
 def get_asset_path(path, themes, files_folders={'files': ''}):
-    """Checks which theme provides the path with the given asset,
-    and returns the "real" path to the asset, relative to the
-    current directory.
+    """
+    .. versionchanghed:: 6.1.0
+
+    Checks which theme provides the path with the given asset,
+    and returns the "real", absolute path to the asset.
 
     If the asset is not provided by a theme, then it will be checked for
     in the FILES_FOLDERS
 
-    >>> print(get_asset_path('assets/css/rst.css', ['bootstrap', 'base']))
-    nikola/data/themes/base/assets/css/rst.css
+    >>> print(get_asset_path('assets/css/rst.css', ['bootstrap', 'base'])) # doctest: +SKIP
+    [...]/nikola/data/themes/base/assets/css/rst.css
 
-    >>> print(get_asset_path('assets/css/theme.css', ['bootstrap', 'base']))
-    nikola/data/themes/bootstrap/assets/css/theme.css
+    >>> print(get_asset_path('assets/css/theme.css', ['bootstrap', 'base'])) # doctest: +SKIP
+    [...]/nikola/data/themes/bootstrap/assets/css/theme.css
 
-    >>> print(get_asset_path('nikola.py', ['bootstrap', 'base'], {'nikola': ''}))
-    nikola/nikola.py
+    >>> print(get_asset_path('nikola.py', ['bootstrap', 'base'], {'nikola': ''})) # doctest: +SKIP
+    [...]/nikola/nikola.py
 
-    >>> print(get_asset_path('nikola/nikola.py', ['bootstrap', 'base'],
-    ... {'nikola':'nikola'}))
-    nikola/nikola.py
+    >>> print(get_asset_path('nikola/nikola.py', ['bootstrap', 'base'], {'nikola':'nikola'})) # doctest: +SKIP
+    [...]/nikola/nikola.py
 
     """
     for theme_name in themes:
@@ -582,14 +597,14 @@ def get_asset_path(path, themes, files_folders={'files': ''}):
             path
         )
         if os.path.isfile(candidate):
-            return os.path.relpath(candidate, sys_decode(os.getcwd()))
+            return candidate
     for src, rel_dst in files_folders.items():
         candidate = os.path.join(
             src,
-            os.path.relpath(path, rel_dst)
+            os.path.abspath(path)
         )
         if os.path.isfile(candidate):
-            return os.path.relpath(candidate, sys_decode(os.getcwd()))
+            return candidate
 
     # whatever!
     return None
@@ -613,3 +628,28 @@ class ExtendedRSS2(rss.RSS2):
                 'type': "application/rss+xml"
             })
             handler.endElement("atom:link")
+
+
+# \x00 means the "<" was backslash-escaped
+explicit_title_re = re.compile(r'^(.+?)\s*(?<!\x00)<(.*?)>$', re.DOTALL)
+
+
+def split_explicit_title(text):
+    """Split role content into title and target, if given.
+
+       From Sphinx's "sphinx/util/nodes.py"
+    """
+    match = explicit_title_re.match(text)
+    if match:
+        return True, match.group(1), match.group(2)
+    return False, text, text
+
+
+def first_line(doc):
+    """extract first non-blank line from text, to extract docstring title"""
+    if doc is not None:
+        for line in doc.splitlines():
+            striped = line.strip()
+            if striped:
+                return striped
+    return ''
